==> DateTime-Locale-1.41.tar.gz: DateTime-Locale-1.41/share/mus-US.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "mus-US",
  date_format_full => "y MMMM d, EEEE",
  date_format_long => "y MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Enhvteceskv",
    "Enhvteceskv Enhvyvtke",
    "Ennvrkvpv",
    "Ennvrkvpv Enhvyvtke",
    "Nak Okkoskv Nettv",
    "Nettv Cakcuse",
    "Nettv Cako",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "Enhvteceskv",
    "Enhvteceskv Enhvyvtke",
    "Ennvrkvpv",
    "Ennvrkvpv Enhvyvtke",
    "Nak Okkoskv Nettv",
    "Nettv Cakcuse",
    "Nettv Cako",
  ],
  day_stand_alone_abbreviated => [
    "Enhvteceskv",
    "Enhvteceskv Enhvyvtke",
    "Ennvrkvpv",
    "Ennvrkvpv Enhvyvtke",
    "Nak Okkoskv Nettv",
    "Nettv Cakcuse",
    "Nettv Cako",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "Enhvteceskv",
    "Enhvteceskv Enhvyvtke",
    "Ennvrkvpv",
    "Ennvrkvpv Enhvyvtke",
    "Nak Okkoskv Nettv",
    "Nettv Cakcuse",
    "Nettv Cako",
  ],
  era_abbreviated => [
    "BCE",
    "CE",
  ],
  era_narrow => [
    "BCE",
    "CE",
  ],
  era_wide => [
    "BCE",
    "CE",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Muscogee",
  month_format_abbreviated => [
    "Rvfo Cuse",
    "Hotvle Hvse",
    "Tasahcuce",
    "Tasahce Rakko",
    "Ke Hvse",
    "Kvco Hvse",
    "Hiyuce",
    "Hiyo Rakko",
    "Otowoskuce",
    "Otowoskv Rakko",
    "Ehole",
    "Rvfo Rakko",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "Rvfo Cuse",
    "Hotvle Hvse",
    "Tasahcuce",
    "Tasahce Rakko",
    "Ke Hvse",
    "Kvco Hvse",
    "Hiyuce",
    "Hiyo Rakko",
    "Otowoskuce",
    "Otowoskv Rakko",
    "Ehole",
    "Rvfo Rakko",
  ],
  month_stand_alone_abbreviated => [
    "Rvfo Cuse",
    "Hotvle Hvse",
    "Tasahcuce",
    "Tasahce Rakko",
    "Ke Hvse",
    "Kvco Hvse",
    "Hiyuce",
    "Hiyo Rakko",
    "Otowoskuce",
    "Otowoskv Rakko",
    "Ehole",
    "Rvfo Rakko",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "Rvfo Cuse",
    "Hotvle Hvse",
    "Tasahcuce",
    "Tasahce Rakko",
    "Ke Hvse",
    "Kvco Hvse",
    "Hiyuce",
    "Hiyo Rakko",
    "Otowoskuce",
    "Otowoskv Rakko",
    "Ehole",
    "Rvfo Rakko",
  ],
  name => "Muscogee United States",
  native_language => "Mvskoke",
  native_name => "Mvskoke United States",
  native_script => undef,
  native_territory => "United States",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => undef,
  territory => "United States",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => "44.1",
}

==> DateTime-Locale-1.42.tar.gz: DateTime-Locale-1.42/share/mus-US.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "mus-US",
  date_format_full => "y MMMM d, EEEE",
  date_format_long => "y MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Enhvteceskv",
    "Enhvteceskv Enhvyvtke",
    "Ennvrkvpv",
    "Ennvrkvpv Enhvyvtke",
    "Nak Okkoskv Nettv",
    "Nettv Cak\N{U+02bc}cuse",
    "Nettv\N{U+02bc}cako",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "Enhvteceskv",
    "Enhvteceskv Enhvyvtke",
    "Ennvrkvpv",
    "Ennvrkvpv Enhvyvtke",
    "Nak Okkoskv Nettv",
    "Nettv Cak\N{U+02bc}cuse",
    "Nettv\N{U+02bc}cako",
  ],
  day_stand_alone_abbreviated => [
    "Enhvteceskv",
    "Enhvteceskv Enhvyvtke",
    "Ennvrkvpv",
    "Ennvrkvpv Enhvyvtke",
    "Nak Okkoskv Nettv",
    "Nettv Cak\N{U+02bc}cuse",
    "Nettv\N{U+02bc}cako",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "Enhvteceskv",
    "Enhvteceskv Enhvyvtke",
    "Ennvrkvpv",
    "Ennvrkvpv Enhvyvtke",
    "Nak Okkoskv Nettv",
    "Nettv Cak\N{U+02bc}cuse",
    "Nettv\N{U+02bc}cako",
  ],
  era_abbreviated => [
    "BCE",
    "CE",
  ],
  era_narrow => [
    "BCE",
    "CE",
  ],
  era_wide => [
    "BCE",
    "CE",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Muscogee",
  month_format_abbreviated => [
    "Rvfo Cuse",
    "Hotvle Hvse",
    "Tasahcuce",
    "Tasahce Rakko",
    "Ke Hvse",
    "Kvco Hvse",
    "Hiyuce",
    "Hiyo Rakko",
    "Otowoskuce",
    "Otowoskv Rakko",
    "Ehole",
    "Rvfo Rakko",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "Rvfo Cuse",
    "Hotvle Hvse",
    "Tasahcuce",
    "Tasahce Rakko",
    "Ke Hvse",
    "Kvco Hvse",
    "Hiyuce",
    "Hiyo Rakko",
    "Otowoskuce",
    "Otowoskv Rakko",
    "Ehole",
    "Rvfo Rakko",
  ],
  month_stand_alone_abbreviated => [
    "Rvfo Cuse",
    "Hotvle Hvse",
    "Tasahcuce",
    "Tasahce Rakko",
    "Ke Hvse",
    "Kvco Hvse",
    "Hiyuce",
    "Hiyo Rakko",
    "Otowoskuce",
    "Otowoskv Rakko",
    "Ehole",
    "Rvfo Rakko",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "Rvfo Cuse",
    "Hotvle Hvse",
    "Tasahcuce",
    "Tasahce Rakko",
    "Ke Hvse",
    "Kvco Hvse",
    "Hiyuce",
    "Hiyo Rakko",
    "Otowoskuce",
    "Otowoskv Rakko",
    "Ehole",
    "Rvfo Rakko",
  ],
  name => "Muscogee United States",
  native_language => "Mvskoke",
  native_name => "Mvskoke United States",
  native_script => undef,
  native_territory => "United States",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => undef,
  territory => "United States",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 45,
}
